
# Slot: increases molecular modification of


holds between two molecular entities where the action or effect of one leads to increased molecular modification(s) of the other (e.g. via post-translational modifications of proteins such as the addition of phosphoryl group, or via redox reaction that adds or subtracts electrons)

URI: [biolink:increases_molecular_modification_of](https://w3id.org/biolink/vocab/increases_molecular_modification_of)

## Domain and Range

[MolecularEntity](MolecularEntity.md) ->  <sub>0..*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects molecular modification of](affects_molecular_modification_of.md)

## Children


## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [Carbohydrate](Carbohydrate.md)
 * [ChemicalSubstance](ChemicalSubstance.md)
 * [CodingSequence](CodingSequence.md)
 * [Drug](Drug.md)
 * [Exon](Exon.md)
 * [Gene](Gene.md)
 * [GeneFamily](GeneFamily.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [Genome](Genome.md)
 * [GenomicEntity](GenomicEntity.md)
 * [Genotype](Genotype.md)
 * [Haplotype](Haplotype.md)
 * [MacromolecularComplex](MacromolecularComplex.md)
 * [MacromolecularMachine](MacromolecularMachine.md)
 * [Metabolite](Metabolite.md)
 * [MicroRNA](MicroRNA.md)
 * [MolecularEntity](MolecularEntity.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
 * [SequenceVariant](SequenceVariant.md)
 * [Transcript](Transcript.md)
